rm(list=ls())

library(ncdf4)
library(s2dverification)
library(abind)

aa<-nc_open('/esarchive/scratch/pjha/hazelnut_outputs/hazelOutputAnal/soil_Ksat.325.200.inv_lat.nc')

lat<-ncvar_get(aa, "lat")
lon<-ncvar_get(aa, "lon")

path_out<-'/esarchive/scratch/pjha/hazelnut_outputs/hazelOutputAnal/plots/'

models<-c('ECHAM5_R1','ECHAM5_R2','ECHAM5_R3','CSIRO-MK3.0_R1','CSIRO-MK3.0_R2','CSIRO-MK3.0_R3',
             'MIROC3.2_R1','MIROC3.2_R2','MIROC3.2_R3','CCCMA3.1_R1','CCCMA3.1_R2','CCCMA3.1_R3')
        
path1<-paste0('/esarchive/scratch/pjha/hazelnut_outputs/hazelOutputAnal/RDS_files/',models,'/','final','/')   
          
## Other variables than phases
name1<-c('yld','fut_yld')

var1<-array(numeric(), c(325,200,19,2,length(models)))
               
for (n in 1:length(models)){ 
  for (i in 1:2) {
    model<-models[n]
    path_in<-path1[n]

        var1[ , , ,i,n]<-readRDS(paste0(path_in,name1[i],'_',model,'.RDS'))

            }

        }



## Mean and std of other variables
var1_avg<-array(numeric(), c(325,200,2,length(models)))
var1_sd<-array(numeric(), c(325,200,2,length(models)))

## 
for (i in 1:2) { ## pres, fut yield
  for (j in 1:length(models)) {
   var1_avg[ , ,i,j]<-apply(drop(var1[ , , ,i,j]),c(1,2),mean)
   var1_sd[ , ,i,j]<-apply(drop(var1[ , , ,i,j]),c(1,2),sd)
   
      }
   }

## rearange dim to make [model,lon,lat]
var1_avg_fin<-aperm(var1_avg, c(4,1,2,3))
rm(var1_avg)
   
var1_sd_fin<-aperm(var1_sd, c(4,1,2,3))  
rm(var1_sd)

###############################################################################################################
######################################### YIELD #######################################
# Average yield (pres climate)
yld_prs_av<-var1_avg_fin[ , , ,1]

#X11()
PlotLayout(PlotEquiMap, c('lat', 'lon'), yld_prs_av[ ,98:189,16:200],lon=lon[98:189], lat=lat[16:200], nrow=4, filled.continents=FALSE, width=8, height=15, bar_limits = c(0,4.0), units = "kg plant-1", 
            cols=c('#f7fcfd','#e5f5f9','#ccece6','#99d8c9','#66c2a4','#41ae76','#238b45','#005824'),
           intylat = 1, intxlon = 1, colNA="white",  titles=paste0(models), 
           toptitle='Average Yield (1990-2009)', 
           title_scale=0.8, title_margin_scale=1.5, extra_margin = c(1,2,1,2),  bar_scale=0.4, fileout=paste0(path_out,'yield/','AvYld_pres_cli_try.png') )
      ##,
      
# Average yiled (fut climate)
yld_fut_av<-var1_avg_fin[ , , ,2]
#X11()
PlotLayout(PlotEquiMap, c('lat', 'lon'),yld_fut_av[ ,98:189,16:200],lon=lon[98:189], lat=lat[16:200], nrow=4, filled.continents=FALSE, width=8, height=15, bar_limits = c(0,4.0), units = "kg plant-1",
            cols=c('#f7fcfd','#e5f5f9','#ccece6','#99d8c9','#66c2a4','#41ae76','#238b45','#005824'),
            col_sup='#00441b',
            intylat = 1, intxlon = 1, colNA="white", titles=paste0(models),
            toptitle='Average Yield (2020-2039)', 
            title_scale=0.8, title_margin_scale=1.5, extra_margin = c(1,2,1,2),  bar_scale=0.4, fileout=paste0(path_out,'yield/','AvYld_fut_cli_try.png'))

